@@ -11,17 +11,20 @@ class Config:
         # 서버로 config() 전송
         pass
 
-    def __setitem__(self):
+    def __setitem__(self, idx):
         pass
 
-    def __getitem__(self):
+    def __getitem__(self, idx, value):
         pass
 
-    def __contains__(self):
+    def __contains__(self, name):
         pass
 
     def get(self, key: str):
-        return self.__dict__[key]
+        if key in self.__dict__:
+            return self.__dict__[key]
+        else:
+            return None
 
     def Items(self):
         return list(self.__dict__.items())
